Crate mimium_scheduler

Crate mimium_scheduler 

Scheduler plugin for mimium.

This plugin provides a simple synchronous event scheduler which is used by the runtime to execute scheduled tasks at sample boundaries.

Structs

SimpleScheduler
Scheduler that checks for ready tasks on every sample and executes them.

Functions

get_default_scheduler_plugin
Return a SystemPlugin with the default synchronous scheduler.