Scheduler plugin for mimium.
This plugin provides a simple synchronous event scheduler which is used by the runtime to execute scheduled tasks at sample boundaries.
Structs
- Simple
Scheduler - Scheduler that checks for ready tasks on every sample and executes them.
Functions
- get_
default_ scheduler_ plugin - Return a
SystemPluginwith the default synchronous scheduler.